package com.weather.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.weather.entity.WeaAuditRotaInfo;

import java.util.List;

/**
 * <p>
 * 产品存储ftp 服务类
 * </p>
 *
 * @author feng
 * @since 2023-09-05
 */
public interface IWeaAuditRotaInfoService extends IService<WeaAuditRotaInfo> {


    /**
     * 查询审核值班信息
     *
     * @param id 审核值班ID
     * @return 审核值班信息
     */
    public WeaAuditRotaInfo selectWeaAuditRotaInfoById(Long id);


    /**
     * 根据年份查询审核值班信息
     *
     * @param rotaYear
     * @return 审核值班信息
     */
    public List<WeaAuditRotaInfo> selectWeaAuditRotaInfoByDate(String rotaYear);

    /**
     * 查询审核值班列表
     *
     * @param weaAuditRotaInfo 审核值班信息
     * @return 审核值班集合
     */
    public List<WeaAuditRotaInfo> selectWeaAuditRotaInfoList(WeaAuditRotaInfo weaAuditRotaInfo);

    /**
     * 新增审核值班
     *
     * @param weaAuditRotaInfo 审核值班信息
     * @return 结果
     */
    public int insertWeaAuditRotaInfo(WeaAuditRotaInfo weaAuditRotaInfo);

    /**
     * 修改审核值班
     *
     * @param weaAuditRotaInfo 审核值班信息
     * @return 结果
     */
    public int updateWeaAuditRotaInfo(WeaAuditRotaInfo weaAuditRotaInfo);

    /**
     * 删除审核值班信息
     *
     * @param id 审核值班ID
     * @return 结果
     */
    public int deleteWeaAuditRotaInfoById(Long id);


}
